Description Usage Arguments Value Examples
Fast Single Population & Normality EDA from a Sampling Plan
1 2 |
data |
A data frame in the long format with three columns representing the "Trial" number for investigating Reproducability, the "Sample" number for investigating Repeatability, and the "Result" column consisting of the measured value. Note, all three columns are numeric columns but only the "Result" column needs to be so and should be a continous variable. The "EDAnorm" function is not intended to be used on discrete data as it's a normality assessement. It should also be noted that the "EDAnorm" function was created to be compatable with the output from the "RCSample" function where the simulated data from the "RCSample" function can be easily feed into the "EDAnorm" function for quick single population and normality EDA. In addition, there are eight data files already created, "EDF1" - "EDF8", that cover differnt types of sampling examples from a manufacturing process with some of them including process shifts. These files cover the situation when the number of "Trials" is > 2 and when the number of "Sample" is > 2 for investigating Repeatability and Reproducability. For the case when the number of "Sample" is <= 2 OR the number of "Trial" is < 3, the "Trial" column is simply ignored and the sampling plan is assummed to consist of single samples pulled and only the underlying population is investigated. There are five data files already created, "CI1" - "CI5", that cover this situation. In this instance only a single population analysis is performed. |
Trial.coded |
"Trial" is defined as the outer stage of the sampling plan describing the processes reproducability. This can be thought of as the time intervals in which a defined number of consecutive "Sample" is drawn and tested from the manufacturing process. |
Sample.coded |
"Sample" is defined as the inner stage of the sampling plan describing the processes repeatability. NOTE: The total number of "Sample" must be > 7 for this analysis. This is due to the normality assessemnt performed in which "Sample" <= 7 are subject to false interpretations of the normality assessments. |
Result.coded |
"Result" is defined as the output from the "Trial" and "Sample" stages measurments. |
sigma_pop |
In the event the total number of "Trial" is < 2 OR the total number of "Sample" <= 2 for each "Trail" a single population EDA is executed. This results in two sided standard error analysis and allows for one to enter a defined / "KNOWN" poplation standard deviation. If this is "UNKNOWN" the NULL value simply uses the "t" statistic for approximating the standard error of the mean. |
p.CI |
In the event the total number of "Trial" is < 2 OR the total number of "Sample" <= 2 for each "Trail" a single population EDA is executed. This results in a two sided standard error analysis and allows for one to enter a defined two sided confidence interval. By default this is set to the two sided 95 two sided confidence interval is needed simply change "p.CI" to the appropriate value. |
The output is a single list containing many of the statistic data set created along with the individual plots created
from the inputs, i.e. data, Trial.coded, Sample.coded, Result.coded, sigma_pop,
&/or p.CI. As shown below it is recommended to save the output of the function to a defined list variable where the
items from the list can be called out specifically.
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 | # When the data is already in the corret format:
saved.output.1 <- EDAnorm(data = EDF1)
saved.output.2 <- EDAnorm(data = CI1, sigma_pop = 7.2)
# If the "Trial", "Sample", and "Result" are defined deferently than what is expressed, simply call them out accordingly.
# In the examples above the "EDF1" & "CI1" data set columns are already coded accordingly and so you don't need to explicitly
# call them out in the function. However, if you do you will still get the same result.
saved.output.3 <- EDAnorm(data = EDF1, Trial.coded = EDF1$Trial, Sample.coded = EDF1$Sample, Result.coded = EDF1$Result)
# To view the last two- three "grid" plots generated in the final listed output, e.g. "grid.newpage_draw_plot1",
# you will need to do the following:
#grid.newpage()
#grid.draw(saved.output.1$grid.newpage_draw_plot1)
#grid.newpage()
#grid.draw(saved.output.1$grid.newpage_draw_plot2)
#grid.newpage()
#grid.draw(saved.output.1$grid.newpage_draw_plot3)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.